@@ -28,6 +28,7 @@ using std::cerr;
 using std::endl;
 #include <sstream>
 #include <string>
+#include <algorithm>
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -42,6 +43,7 @@ using std::endl;
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
+#include <ctype.h>
 
 #include "kino_common.h"
 #include "page_editor.h"
@@ -294,7 +296,7 @@ void KinoCommon::fetchProjectMetadata( const std::string& projectKey )
 	pages are informed of the action through their own newFile method.
 */
 
-bool KinoCommon::newFile( bool prompt )
+bool KinoCommon::newFile( bool prompt, bool isExiting )
 {
 	bool result = true;
 
@@ -304,7 +306,7 @@ bool KinoCommon::newFile( bool prompt )
 	this->changePageRequest( PAGE_EDITOR );
 	if ( getPlayList() ->IsDirty() )
 	{
-		switch ( modal_confirm( GTK_STOCK_SAVE, GTK_STOCK_CLOSE, _("Save changes to project \"%s\" before closing?"),
+		switch ( modal_confirm( GTK_STOCK_SAVE, isExiting? GTK_STOCK_QUIT: GTK_STOCK_NEW, _("Save changes to project \"%s\" before closing?"),
 			 getPlayList()->GetDocName() == "" ? _("Untitled") : getPlayList()->GetDocName().c_str() ) )
 		{
 		case GTK_RESPONSE_ACCEPT:
@@ -332,13 +334,12 @@ bool KinoCommon::newFile( bool prompt )
 		{
 			string buffer;
 
-			buffer = _( "The following fx rendered files are no longer used: \n\n" );
 			vector < string >::iterator it;
 			for ( it = list.begin(); it != list.end(); it ++ )
 				buffer += *it + "\n";
-			buffer += _( "\nDo you want me to delete them now?" );
 
-			switch ( modal_confirm( GTK_STOCK_DELETE, GTK_STOCK_CLOSE, buffer.c_str() ) )
+			switch ( modal_confirm_files( GTK_STOCK_DELETE, GTK_STOCK_CLOSE, buffer.c_str(), 
+				_( "The following FX rendered files are no longer used.\nDo you want me to delete them now?" ) ) )
 			{
 			case GTK_RESPONSE_ACCEPT:
 				for ( it = list.begin(); it != list.end(); it ++ )
@@ -571,7 +572,7 @@ std::string KinoCommon::importFile( const char *filename )
 		_("\"%s\" is not a DV file. Do you want to import it?"), filename )
 		== GTK_RESPONSE_ACCEPT )
 	{
-		char * args[ 7 ];
+		const char * args[ 7 ];
 		int pid, status = -1;
 		GError *gerror = NULL;
 		gboolean visible = TRUE;
@@ -645,8 +646,8 @@ std::string KinoCommon::importFile( const char *filename )
 		importedFile = StringUtils::replaceAll( importedFile, "\"", "\\\"") + std::string( ".dv" );
 		
 		args[ 0 ] = DATADIR "/kino/scripts/import/media.sh";
-		args[ 1 ] = const_cast<char*>( filename );
-		args[ 2 ] = const_cast<char*>( importedFile.c_str() );
+		args[ 1 ] = filename;
+		args[ 2 ] = importedFile.c_str();
 		args[ 6 ] = NULL;
 
 		// Allow a script in home directory to override
@@ -657,7 +658,7 @@ std::string KinoCommon::importFile( const char *filename )
 			args[ 0 ] = const_cast< char* >( homeFile.c_str() );
 		}
 
-		g_spawn_async_with_pipes( ".", args, NULL, G_SPAWN_DO_NOT_REAP_CHILD,
+		g_spawn_async_with_pipes( ".", (gchar**) args, NULL, G_SPAWN_DO_NOT_REAP_CHILD,
 			NULL, NULL, &pid, NULL, NULL, NULL, &gerror );
 		
 		// Check for cancellation or child exit
@@ -1101,24 +1102,35 @@ char *KinoCommon::getFileToOpen( char *title, bool isDVFile, GtkWidget *widget )
 		filter = gtk_file_filter_new();
 		gtk_file_filter_set_name( filter, "SMIL Files (*.smil, *.kino)" );
 		gtk_file_filter_add_pattern( filter, "*.smil" );
+		gtk_file_filter_add_pattern( filter, "*.SMIL" );
 		gtk_file_filter_add_pattern( filter, "*.kino" );
+		gtk_file_filter_add_pattern( filter, "*.Kino" );
+		gtk_file_filter_add_pattern( filter, "*.KINO" );
 		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
 	
 		filter = gtk_file_filter_new();
 		gtk_file_filter_set_name( filter, "Raw DV Files (*.dv, *.dif)" );
 		gtk_file_filter_add_pattern( filter, "*.dv" );
 		gtk_file_filter_add_pattern( filter, "*.dif" );
+		gtk_file_filter_add_pattern( filter, "*.DV" );
+		gtk_file_filter_add_pattern( filter, "*.Dv" );
+		gtk_file_filter_add_pattern( filter, "*.DIF" );
+		gtk_file_filter_add_pattern( filter, "*.Dif" );
 		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
 	
 		filter = gtk_file_filter_new();
 		gtk_file_filter_set_name( filter, "AVI Files (*.avi)" );
 		gtk_file_filter_add_pattern( filter, "*.avi" );
+		gtk_file_filter_add_pattern( filter, "*.AVI" );
+		gtk_file_filter_add_pattern( filter, "*.Avi" );
 		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
 	
 #ifdef HAVE_LIBQUICKTIME
 		filter = gtk_file_filter_new();
 		gtk_file_filter_set_name( filter, "Quicktime Files (*.mov)" );
 		gtk_file_filter_add_pattern( filter, "*.mov" );
+		gtk_file_filter_add_pattern( filter, "*.MOV" );
+		gtk_file_filter_add_pattern( filter, "*.Mov" );
 		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
 #endif
 	}
@@ -1253,7 +1265,8 @@ int KinoCommon::checkFile( char *FileName )
 
 	// Start looking at file suffixes ...
 	const std::string filename( FileName );
-	const std::string suffix( filename.begin() + filename.rfind( "." ), filename.end() );
+	std::string suffix( filename.begin() + filename.rfind( "." ), filename.end() );
+	std::transform( suffix.begin(), suffix.end(), suffix.begin(), ::tolower );
 
 	if ( suffix == ".avi" )
 	{
@@ -1758,7 +1771,7 @@ gboolean KinoCommon::processKeyboard( GdkEventKey *event )
 	either keyboard or command line style strings.
 */
 
-gboolean KinoCommon::processCommand( char *cmd )
+gboolean KinoCommon::processCommand( const char *cmd )
 {
 	return getCurrentPage() ->processCommand( cmd );
 }
@@ -2300,7 +2313,7 @@ void KinoCommon::setStatusBar( const char * msg, ... )
 
 bool KinoCommon::exitKino( )
 {
-	return newFile( false );
+	return newFile( false, true );
 }
 
 void KinoCommon::setTimeFormat( SMIL::Time::TimeFormat format )
@@ -2349,12 +2362,12 @@ void KinoCommon::publishPlayList()
 		command << "\"" << filename << "\" ";
 		command << "\"" << playlist.GetDocId().c_str() << "\" ";
 		command << "\"" << playlist.GetDocTitle().c_str() << "\" ";
-		char * args[ 4 ];
+		const char * args[ 4 ];
 		args[ 0 ] = "/bin/sh";
 		args[ 1 ] = "-c";
-		args[ 2 ] = const_cast< char* >( command.str().c_str() );
+		args[ 2 ] = command.str().c_str();
 		args[ 3 ] = NULL;
-		g_spawn_sync( ".", args, NULL, (GSpawnFlags)0, NULL, NULL, NULL, NULL, NULL, &gerror );
+		g_spawn_sync( ".", (gchar**) args, NULL, (GSpawnFlags)0, NULL, NULL, NULL, NULL, NULL, &gerror );
 		unlink( filename );
 	}
 	else
@@ -2364,12 +2377,12 @@ void KinoCommon::publishPlayList()
 		command << "\"" << playlist.GetDocName() << "\" ";
 		command << "\"" << playlist.GetDocId().c_str() << "\" ";
 		command << "\"" << playlist.GetDocTitle().c_str() << "\" ";
-		char * args[ 4 ];
+		const char * args[ 4 ];
 		args[ 0 ] = "/bin/sh";
 		args[ 1 ] = "-c";
-		args[ 2 ] = const_cast< char* >( command.str().c_str() );
+		args[ 2 ] = command.str().c_str();
 		args[ 3 ] = NULL;
-		g_spawn_async_with_pipes( ".", args, NULL, (GSpawnFlags)0, NULL, NULL, NULL, NULL, NULL, NULL, &gerror );
+		g_spawn_async_with_pipes( ".", (gchar**) args, NULL, (GSpawnFlags)0, NULL, NULL, NULL, NULL, NULL, NULL, &gerror );
 	}
 }
 
@@ -2394,12 +2407,12 @@ void KinoCommon::publishFrame()
 			command << "\"" << getPlayList()->GetDocId().c_str() << "\" ";
 			command << "\"" << getPlayList()->GetSeqAttribute( g_currentFrame, "title" ) << "\" ";
 			command << "\"" << getPlayList()->GetDocTitle().c_str() << "\" ";
-			char * args[ 4 ];
+			const char * args[ 4 ];
 			args[ 0 ] = "/bin/sh";
 			args[ 1 ] = "-c";
-			args[ 2 ] = const_cast< char* >( command.str().c_str() );
+			args[ 2 ] = command.str().c_str();
 			args[ 3 ] = NULL;
-			g_spawn_async_with_pipes( ".", args, NULL, (GSpawnFlags)0, NULL, NULL, NULL, NULL, NULL, NULL, &gerror );
+			g_spawn_async_with_pipes( ".", (gchar**) args, NULL, (GSpawnFlags)0, NULL, NULL, NULL, NULL, NULL, NULL, &gerror );
 		}
 	}
 	
