@@ -822,7 +822,7 @@ gboolean PageCapture::processKeyboard( GdkEventKey *event )
   	\param cmd		command to be processed;
 */
 
-gboolean PageCapture::processCommand( char *command )
+gboolean PageCapture::processCommand( const char *command )
 {
 	int count = 1;
 	char real[ 256 ] = "";
