@@ -359,7 +359,7 @@ void Plugin::Close( )
 		dlclose( ptr );
 }
 
-void *Plugin::Find( char *symbol )
+void *Plugin::Find( const char *symbol )
 {
 	return dlsym( ptr, symbol );
 }
@@ -384,7 +384,7 @@ PluginCollection::~PluginCollection( )
 	}
 }
 
-void PluginCollection::Initialise( char *directory )
+void PluginCollection::Initialise( const char *directory )
 {
 	char * filename;
 	char *extension;
@@ -2451,7 +2451,9 @@ void PageMagick::selectScene( int i )
 	{
 		GtkSpinButton *startSpin = GTK_SPIN_BUTTON( lookup_widget( window, "spinbutton_magick_start" ) );
 		GtkSpinButton *endSpin = GTK_SPIN_BUTTON( lookup_widget( window, "spinbutton_magick_end" ) );
+		gtk_spin_button_set_range( startSpin, 0, end );
 		gtk_spin_button_set_value( startSpin, begin );
+		gtk_spin_button_set_range( endSpin, begin, common->getPlayList() ->GetNumFrames() - 1 );
 		gtk_spin_button_set_value( endSpin, end );
 
 		if ( previewing )
@@ -2724,7 +2726,7 @@ gboolean PageMagick::processKeyboard( GdkEventKey *event )
 	return ret;
 }
 
-gboolean PageMagick::processCommand( char *cmd )
+gboolean PageMagick::processCommand( const char *cmd )
 {
 	/* play, pause */
 
@@ -2840,7 +2842,7 @@ gboolean PageMagick::processCommand( char *cmd )
 		ev.key.send_event = TRUE;
 		ev.key.state = 0;
 		ev.key.length = 0;
-		ev.key.string = "";
+		ev.key.string = (gchar*) "";
 		ev.key.keyval = GDK_Return;
 		ev.key.group = 0;
 		gdk_event_put( &ev );
@@ -3282,6 +3284,11 @@ public:
 	{
 		return magick->IsPreviewing();
 	}
+
+	int GetFrameNumber( double position )
+	{
+		return start + GetIndex( position );
+	}
 };
 
 // Get the selected frames for FX
